@@ -15,10 +15,10 @@ class LoadPretrainedModelTest(tf.test.TestCase):
     def _do_predict(self, model):
         input_ids = tf.constant([1, 2, 3, 4, 5, 6, 7, 8], shape=(2, 4))
         # output_1 should be all close to output_2
-        _, outputs_1 = model.predict((input_ids,))
+        _, outputs_1 = model(input_ids, None, None, training=False)
         print(outputs_1)
-        _, outputs_2 = model(inputs=(input_ids,))
-        print(outputs_2)
+        # _, outputs_2 = model(input_ids, None, None)
+        # print(outputs_2)
 
     def test_load_pretrained_bert(self):
         model_paths = [
@@ -65,7 +65,7 @@ class LoadPretrainedModelTest(tf.test.TestCase):
             bert = Bert.from_pretrained(os.path.join(BASE_DIR, 'chinese_roberta_wwm_ext_L-12_H-768_A-12'))
             bert.trainable = trainable
 
-            sequence_output, pooled_output = bert(inputs=(input_ids, segment_ids))
+            sequence_output, pooled_output = bert(input_ids, segment_ids, None)
             outputs = tf.keras.layers.Dense(2, name='output')(pooled_output)
             model = tf.keras.Model(inputs=[input_ids, segment_ids], outputs=outputs)
             model.compile(loss='binary_cross_entropy', optimizer='adam')
@@ -84,7 +84,7 @@ class LoadPretrainedModelTest(tf.test.TestCase):
             albert = Albert.from_pretrained(os.path.join(BASE_DIR, 'albert_base_zh'))
             albert.trainable = trainable
 
-            sequence_output, pooled_output = albert(inputs=(input_ids, segment_ids))
+            sequence_output, pooled_output = albert(input_ids, segment_ids, None)
             outputs = tf.keras.layers.Dense(2, name='output')(pooled_output)
             model = tf.keras.Model(inputs=[input_ids, segment_ids], outputs=outputs)
             model.compile(loss='binary_cross_entropy', optimizer='adam')
